@@ -53,7 +53,8 @@ register restrpc => sub {
 
     debug("Starting restrpc-handler build: ", $lister);
     my $handle_call = sub {
-        if (request->content_type ne 'application/json') {
+        my ($ct) = (split /;\s*/, request->content_type, 2);
+        if ($ct ne 'application/json') {
             pass();
         }
         debug("[handle_restrpc_request] Processing: ", request->body);
@@ -77,22 +78,28 @@ register restrpc => sub {
         };
 
         if (my $error = $@) {
-            $response = Dancer::RPCPlugin::ErrorResponse->new(
+            my $error_response = Dancer::RPCPlugin::ErrorResponse->new(
                 error_code => 500,
                 error_message => $error,
-            )->as_restrpc_error;
+            );
+            status $error_response->return_status('restrpc');
+            $response = $error_response->as_restrpc_error;
         }
         elsif (!blessed($continue) || !$continue->isa('Dancer::RPCPlugin::CallbackResult')) {
-            $response = Dancer::RPCPlugin::ErrorResponse->new(
+            my $error_response = Dancer::RPCPlugin::ErrorResponse->new(
                 error_code    => 500,
                 error_message => "Internal error: 'callback_result' wrong class " . blessed($continue),
-            )->as_restrpc_error;
+            );
+            status $error_response->return_status('restrpc');
+            $response = $error_response->as_restrpc_error;
         }
         elsif (blessed($continue) && !$continue->success) {
-            $response = Dancer::RPCPlugin::ErrorResponse->new(
+            my $error_response = Dancer::RPCPlugin::ErrorResponse->new(
                 error_code    => $continue->error_code,
                 error_message => $continue->error_message,
-            )->as_restrpc_error;
+            );
+            status $error_response->return_status('restrpc');
+            $response = $error_response->as_restrpc_error;
         }
         else {
             my Dancer::RPCPlugin::DispatchItem $di = $dispatcher->{$method_name};
@@ -118,7 +125,11 @@ register restrpc => sub {
             }
         }
         $response = { result => $response } if !ref($response);
-        return to_json($response);
+        my $jsonise_options = {canonical => 1};
+        if (config->{encoding} && config->{encoding} =~ m{^utf-?8$}i) {
+            $jsonise_options->{utf8} = 1;
+        }
+        return to_json($response, $jsonise_options);
     };
 
     debug("setting routes (restrpc): $base_url ", $lister);
@@ -129,11 +140,12 @@ register restrpc => sub {
 };
 
 sub build_dispatcher_from_pod {
-    my ($pkgs) = @_;
+    my ($pkgs, $endpoint) = @_;
     debug("[build_dispatcher_from_pod]");
     return dispatch_table_from_pod(
+        plugin   => 'restrpc',
         packages => $pkgs,
-        label    => 'restrpc',
+        endpoint => $endpoint,
     );
 }
 
@@ -142,7 +154,7 @@ sub build_dispatcher_from_config {
     debug("[build_dispatcher_from_config] ");
 
     return dispatch_table_from_config(
-        key      => 'restrpc',
+        plugin   => 'restrpc',
         config   => $config,
         endpoint => $endpoint,
     );
